
/**
 * GMyth Library
 *
 * @file gmyth/gmyth_backend_info.c
 * 
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Hallyson Melo <hallyson.melo@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "gmyth_backendinfo.h"
#include "gmyth_uri.h"

static void gmyth_backend_info_class_init  (GMythBackendInfoClass *klass);
static void gmyth_backend_info_init        (GMythBackendInfo *object);

static void gmyth_backend_info_dispose  (GObject *object);
static void gmyth_backend_info_finalize (GObject *object);

G_DEFINE_TYPE(GMythBackendInfo, gmyth_backend_info, G_TYPE_OBJECT)
    
static void
gmyth_backend_info_class_init (GMythBackendInfoClass *klass)
{
    GObjectClass *gobject_class;

    gobject_class = (GObjectClass *) klass;

    gobject_class->dispose  = gmyth_backend_info_dispose;
    gobject_class->finalize = gmyth_backend_info_finalize;	
}

static void
gmyth_backend_info_init (GMythBackendInfo *backend_info)
{
    backend_info->hostname = NULL;
    backend_info->username = NULL;
    backend_info->password = NULL;
    backend_info->db_name  = NULL;
    backend_info->port = -1;
}

static void
gmyth_backend_info_dispose  (GObject *object)
{
    GMythBackendInfo *backend_info = GMYTH_BACKEND_INFO (object);

    g_free (backend_info->hostname);
    g_free (backend_info->username);
    g_free (backend_info->password);
    g_free (backend_info->db_name);

    backend_info->hostname = NULL;
    backend_info->username = NULL;
    backend_info->password = NULL;
    backend_info->db_name  = NULL;
    backend_info->port = -1;

    G_OBJECT_CLASS (gmyth_backend_info_parent_class)->dispose (object);
}

static void
gmyth_backend_info_finalize (GObject *object)
{
    g_signal_handlers_destroy (object);

    G_OBJECT_CLASS (gmyth_backend_info_parent_class)->finalize (object);
}

/** Creates a new instance of GMythBackendInfo.
 * 
 * @return a new instance of GMythBackendInfo.
 */
GMythBackendInfo*
gmyth_backend_info_new ()
{
    GMythBackendInfo *backend_info = 
        GMYTH_BACKEND_INFO (g_object_new(GMYTH_BACKEND_INFO_TYPE, NULL));
    
    return backend_info;
}

GMythBackendInfo*
gmyth_backend_info_new_full (const char *hostname, const char *username,
	const char *password, const char *db_name, gint port)
{
    GMythBackendInfo *backend_info = 
        GMYTH_BACKEND_INFO (g_object_new(GMYTH_BACKEND_INFO_TYPE, NULL));
    
    gmyth_backend_info_set_hostname (backend_info, hostname);
    gmyth_backend_info_set_username (backend_info, username);
    gmyth_backend_info_set_password (backend_info, password);
    gmyth_backend_info_set_db_name (backend_info, db_name);
    gmyth_backend_info_set_port (backend_info, port);

    return backend_info;
}

GMythBackendInfo*
gmyth_backend_info_new_with_uri (const gchar *uri_str )
{
    GMythBackendInfo *backend_info = 
        GMYTH_BACKEND_INFO (g_object_new(GMYTH_BACKEND_INFO_TYPE, NULL));
        
    GMythURI* uri = gmyth_uri_new( (gchar*)uri_str );
    
    gmyth_backend_info_set_hostname (backend_info, gmyth_uri_get_host (uri ) );
    gmyth_backend_info_set_username (backend_info, gmyth_uri_get_user( uri ) );
    gmyth_backend_info_set_password (backend_info, gmyth_uri_get_password( uri ) );
    gmyth_backend_info_set_db_name (backend_info, gmyth_uri_get_path( uri ) );
    gmyth_backend_info_set_port (backend_info, gmyth_uri_get_port( uri ) );

    return backend_info;
}

void
gmyth_backend_info_set_hostname (GMythBackendInfo *backend_info, const char *hostname)
{
    g_return_if_fail (backend_info != NULL);

    backend_info->hostname = g_strdup (hostname);
}

void
gmyth_backend_info_set_username (GMythBackendInfo *backend_info, const char *username)
{
    g_return_if_fail (backend_info != NULL);

    backend_info->username = g_strdup (username);
}

void
gmyth_backend_info_set_password (GMythBackendInfo *backend_info, const char *password)
{
    g_return_if_fail (backend_info != NULL);

    backend_info->password = g_strdup (password);
}

void
gmyth_backend_info_set_db_name (GMythBackendInfo *backend_info, const char *db_name)
{
    g_return_if_fail (backend_info != NULL);

    backend_info->db_name = g_strdup (db_name);
}

void
gmyth_backend_info_set_port (GMythBackendInfo *backend_info, const gint port )
{
    g_return_if_fail (backend_info != NULL);

    backend_info->port = port;
}

char*
gmyth_backend_info_get_hostname (GMythBackendInfo *backend_info)
{
    g_return_val_if_fail (backend_info != NULL, NULL);

    return backend_info->hostname;
}

char*
gmyth_backend_info_get_username (GMythBackendInfo *backend_info)
{
    g_return_val_if_fail (backend_info != NULL, NULL);

    return backend_info->username;
}

char*
gmyth_backend_info_get_password (GMythBackendInfo *backend_info)
{
    g_return_val_if_fail (backend_info != NULL, NULL);

    return backend_info->password;
}

char*
gmyth_backend_info_get_db_name (GMythBackendInfo *backend_info)
{
    g_return_val_if_fail (backend_info != NULL, NULL);

    return backend_info->db_name;
}

gint
gmyth_backend_info_get_port (GMythBackendInfo *backend_info)
{
    g_return_val_if_fail (backend_info != NULL, -1);

    return backend_info->port;
}
